@@ -8,14 +8,14 @@ def safe_strftime(value, format='%m/%d/%Y %H:%M', on_none=''):
         return on_none
     return value.strftime(format)
 
-def ensure_datetime(dobj):
+def ensure_datetime(dobj, time_part=None):
     """
         Adds time part to dobj if its a date object, returns dobj
         untouched if its a datetime object.
     """
     if isinstance(dobj, dt.datetime):
         return dobj
-    return dt.datetime.combine(dobj, dt.time())
+    return dt.datetime.combine(dobj, time_part or dt.time())
 
 def ensure_date(dobj):
     """
